==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/pl/compress.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl" sourcelanguage="en">
<context>
    <name>CompressPlugin</name>
    <message>
        <source>Unsupported compression method</source>
        <translation>Nieobsługiwana metoda kompresji</translation>
    </message>
    <message>
        <source>Compression setup failed</source>
        <translation>Nie udało się zainicjować kompresji</translation>
    </message>
    <message>
        <source>Stream Compression</source>
        <translation>Kompresja strumienia XMPP</translation>
    </message>
    <message>
        <source>Allows to compress a stream of messages sent and received from the server</source>
        <translation>Pozwala na kompresję strumienia wiadomości wysłanych i odebranych z serwera</translation>
    </message>
</context>
<context>
    <name>Compression</name>
    <message>
        <source>Invalid compression level</source>
        <translation>Nieprawidłowy stopień kompresji</translation>
    </message>
    <message>
        <source>invalid or incomplete deflate data</source>
        <translation>nieprawidłowe lub niepełne dane do kompresji</translation>
    </message>
    <message>
        <source>Out of memory for Zlib</source>
        <translation>Brak pamięci dla Zlib</translation>
    </message>
    <message>
        <source>Zlib version mismatch!</source>
        <translation>Nieprawidłowa wersja Zlib!</translation>
    </message>
    <message>
        <source>Wrong compression negotiation response</source>
        <translation>Zła odpowiedź podczas inicjalizacji kompresji</translation>
    </message>
</context>
</TS>

==> vacuum-1.1.2_1798.tar.xz: vacuum-1.1.2_1798/src/translations/pl/compress.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl" sourcelanguage="en">
<context>
    <name>CompressPlugin</name>
    <message>
        <source>Unsupported compression method</source>
        <translation>Nieobsługiwana metoda kompresji</translation>
    </message>
    <message>
        <source>Compression setup failed</source>
        <translation>Nie udało się zainicjować kompresji</translation>
    </message>
    <message>
        <source>Stream Compression</source>
        <translation>Kompresja strumienia XMPP</translation>
    </message>
    <message>
        <source>Allows to compress a stream of messages sent and received from the server</source>
        <translation>Pozwala na kompresję strumienia wiadomości wysłanych i odebranych z serwera</translation>
    </message>
    <message>
        <source>Enable data compression transferred between client and server</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Compression</name>
    <message>
        <source>Invalid compression level</source>
        <translation>Nieprawidłowy stopień kompresji</translation>
    </message>
    <message>
        <source>Out of memory for Zlib</source>
        <translation>Brak pamięci dla Zlib</translation>
    </message>
    <message>
        <source>Zlib version mismatch!</source>
        <translation>Nieprawidłowa wersja Zlib!</translation>
    </message>
    <message>
        <source>Wrong compression negotiation response</source>
        <translation>Zła odpowiedź podczas inicjalizacji kompresji</translation>
    </message>
    <message>
        <source>Invalid or incomplete deflate data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown Zlib error, %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
